/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd All Rights Reserved
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
/**
 * @file        src/common/exceptions/Exception.h
 * @author      Aleksander Zdyb <a.zdyb@samsung.com>
 * @version     1.0
 * @brief       Header for generic Cynara exception
 */
#ifndef SRC_COMMON_EXCEPTIONS_EXCEPTION_H_
#define SRC_COMMON_EXCEPTIONS_EXCEPTION_H_

#include <exception>
#include <log/Backtrace.h>

namespace Cynara {

class Exception : public std::exception {
public:
    Exception() {
        m_backtrace = Backtrace::getBacktrace();
    }

    virtual ~Exception() {};

    virtual const char *what(void) const noexcept {
        if(m_whatMessage.empty()) {
            try {
                m_whatMessage = message() + " From: " + m_backtrace;
            }
            catch (...) {
            }
        }
        return m_whatMessage.c_str();
    }

    virtual const std::string &message(void) const = 0;

private:
    std::string m_backtrace;
    mutable std::string m_whatMessage;
};

} /* namespace Cynara */

#endif /* SRC_COMMON_EXCEPTIONS_EXCEPTION_H_ */
